pub struct ContentBoxItemLayout {
pub anchors: Rect,
pub margin: Rect,
pub align: Vec2,
pub offset: Vec2,
pub depth: Scalar,
pub keep_in_bounds: ContentBoxItemKeepInBounds,
}Expand description
Allows customizing how an item in a content_box is laid out
Fields
anchors: Rectmargin: RectThe margins to put on each side of the item
align: Vec2Tells in percentage, where is the center of mass of the widget, relative to it’s box size
offset: Vec2The amount to offset the item from where it would otherwise be laid out
depth: ScalarThe “Z” depth of the item
keep_in_bounds: ContentBoxItemKeepInBoundsSet of constraints that tell if and how to keep item in container bounds